==> haskell-sdl2-ttf-2.1.3-209-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sdl2-ttf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   sdl2-ttf
version:                2.1.3
visibility:             public
id:                     sdl2-ttf-2.1.3-Cm89Jk2KLHDLpJFVBDsevU
key:                    sdl2-ttf-2.1.3-Cm89Jk2KLHDLpJFVBDsevU
license:                BSD-3-Clause
copyright:
    Copyright © 2013-2022 Ömer Sinan Ağacan, Siniša Biđin, Rongcui Dong and others (see git commits)

maintainer:             Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:
    Rongcui Dong (rongcuid@outlook.com),
    Siniša Biđin <sinisa@bidin.eu>,
    Ömer Sinan Ağacan (omeragacan@gmail.com),
    Sean Chalmers (sclhiannan@gmail.com)

synopsis:               Bindings to SDL2_ttf.
description:
    Haskell bindings to SDL2_ttf C++ library <https://github.com/libsdl-org/SDL_ttf>.

category:               Font, Foreign binding, Graphics
abi:                    a82a3a2c533f29e6c6b0a3914d7ce834
exposed:                True
exposed-modules:        SDL.Font SDL.Raw.Font
hidden-modules:         SDL.Raw.Helper
import-dirs:            /usr/lib/ghc-9.4.8/site-local/sdl2-ttf-2.1.3
library-dirs:           /usr/lib/ghc-9.4.8/site-local/sdl2-ttf-2.1.3
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/sdl2-ttf-2.1.3
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-sdl2-ttf
hs-libraries:           HSsdl2-ttf-2.1.3-Cm89Jk2KLHDLpJFVBDsevU
extra-libraries:        SDL2_ttf SDL2
extra-libraries-static:
    SDL2_ttf SDL2 freetype bz2 png16 m m z harfbuzz m glib-2.0 m
    sysprof-capture-4 pcre2-8 graphite2 brotlidec brotlicommon

include-dirs:
    /usr/include/SDL2 /usr/include/freetype2 /usr/include/libpng16
    /usr/include/harfbuzz /usr/include/glib-2.0
    /usr/lib/glib-2.0/include /usr/include/sysprof-6

depends:
    base-4.17.2.1 bytestring-0.11.5.3
    sdl2-2.5.5.1-6bAPlgR2p2SJ1AC0F7F7Xx template-haskell-2.19.0.0
    text-2.0.2 th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy
    transformers-0.5.6.2

haddock-interfaces:     /usr/share/doc/haskell-sdl2-ttf/html/sdl2-ttf.haddock
haddock-html:           /usr/share/doc/haskell-sdl2-ttf/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sdl2-ttf-2.1.3-210-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sdl2-ttf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   sdl2-ttf
version:                2.1.3
visibility:             public
id:                     sdl2-ttf-2.1.3-B8iQbCMJqhELFBY6UVv507
key:                    sdl2-ttf-2.1.3-B8iQbCMJqhELFBY6UVv507
license:                BSD-3-Clause
copyright:
    Copyright © 2013-2022 Ömer Sinan Ağacan, Siniša Biđin, Rongcui Dong and others (see git commits)

maintainer:             Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:
    Rongcui Dong (rongcuid@outlook.com),
    Siniša Biđin <sinisa@bidin.eu>,
    Ömer Sinan Ağacan (omeragacan@gmail.com),
    Sean Chalmers (sclhiannan@gmail.com)

synopsis:               Bindings to SDL2_ttf.
description:
    Haskell bindings to SDL2_ttf C++ library <https://github.com/libsdl-org/SDL_ttf>.

category:               Font, Foreign binding, Graphics
abi:                    09bd83f98d2fb8280b5d3c1c8e7ad09f
exposed:                True
exposed-modules:        SDL.Font SDL.Raw.Font
hidden-modules:         SDL.Raw.Helper
import-dirs:            /usr/lib/ghc-9.4.8/site-local/sdl2-ttf-2.1.3
library-dirs:           /usr/lib/ghc-9.4.8/site-local/sdl2-ttf-2.1.3
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/sdl2-ttf-2.1.3
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-sdl2-ttf
hs-libraries:           HSsdl2-ttf-2.1.3-B8iQbCMJqhELFBY6UVv507
extra-libraries:        SDL2_ttf SDL2
extra-libraries-static:
    SDL2_ttf SDL2 freetype bz2 png16 m m z harfbuzz m glib-2.0 m
    sysprof-capture-4 pcre2-8 graphite2 brotlidec brotlicommon

include-dirs:
    /usr/include/SDL2 /usr/include/freetype2 /usr/include/libpng16
    /usr/include/harfbuzz /usr/include/glib-2.0
    /usr/lib/glib-2.0/include /usr/include/sysprof-6

depends:
    base-4.17.2.1 bytestring-0.11.5.3
    sdl2-2.5.5.1-HGIwPpkZXaz64UDryXwxq1 template-haskell-2.19.0.0
    text-2.0.2 th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy
    transformers-0.5.6.2

haddock-interfaces:     /usr/share/doc/haskell-sdl2-ttf/html/sdl2-ttf.haddock
haddock-html:           /usr/share/doc/haskell-sdl2-ttf/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
